@@ -111,9 +111,13 @@ void ProfileChangerWidget::onChangeProfileClicked() {
         this->usageCounter = 0;
         if(PCW_APP_DEVEL) {
             QString tmpInfo;
-            tmpInfo.append(tr("You installed a Profile Changer Widget from Extras-devel repository."));
+            tmpInfo.append(tr("You installed Profile Changer Widget from Extras-devel repository."));
             tmpInfo.append("\n");
             tmpInfo.append(tr("Don't play with Extras-devel if you haven't backed up your data or aren't prepared to re-flash your device."));
+            tmpInfo.append("\n");
+            tmpInfo.append(tr("This warning does not exist with versions that are pushed to Extras-testing or Extras repository."));
+            tmpInfo.append("\n");
+            tmpInfo.append(tr("Please test the most current version from Extras-testing."));
             this->showQuestion(tmpInfo);
         }
     }
