@@ -9,10 +9,10 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     ui->setupUi(this);
     setAttribute(Qt::WA_DeleteOnClose);
     QSettings settings;
-    ui->heightBox->setValue(settings.value(PCW_SETTING_HEIGHT).toInt());
-    ui->widthBox->setValue(settings.value(PCW_SETTING_WIDTH).toInt());
-    ui->spinBoxOpacity->setValue(settings.value(PCW_SETTING_OPACITY).toInt());
-    ui->checkBoxNextProfile->setChecked(settings.value(PCW_SETTING_SHOWNEXTPROFILE).toBool());
+    ui->heightBox->setValue(settings.value(PCW_SETTING_HEIGHT, PCW_SETTING_HEIGHT_DEFAULT).toInt());
+    ui->widthBox->setValue(settings.value(PCW_SETTING_WIDTH, PCW_SETTING_WIDTH_DEFAULT).toInt());
+    ui->spinBoxOpacity->setValue(settings.value(PCW_SETTING_OPACITY, PCW_SETTING_OPACITY_DEFAULT).toInt());
+    ui->checkBoxNextProfile->setChecked(settings.value(PCW_SETTING_SHOWNEXTPROFILE, PCW_SETTING_SHOWNEXTPROFILE_DEFAULT).toBool());
     connect(this, SIGNAL(rejected()), this, SLOT(close()));
 }
 
@@ -67,17 +67,17 @@ void SettingsDialog::showAbout()
 
 void SettingsDialog::checkVersion() {
     QSettings settings;
-    QString oldVersion = settings.value(PCW_SETTING_LASTVERSION).toString();
+    QString oldVersion = settings.value(PCW_SETTING_LASTVERSION, PCW_SETTING_LASTVERSION_DEFAULT).toString();
     QString curVersion = QApplication::applicationVersion();
     if(oldVersion != curVersion) {
         settings.setValue(PCW_SETTING_LASTVERSION, curVersion);
         QString tmpInfo;
         if(oldVersion == PCW_SETTING_LASTVERSION_DEFAULT) {
             //Show info for user that have installed the app for the first time.
-            tmpInfo.append(tr("Thank you for installing profile changer widget."));
+            tmpInfo.append(tr("Thank you for installing profile changer widget version %1.").arg(curVersion));
         } else {
             //Show update info
-            tmpInfo.append(tr("Thank you for updating profile changer widget."));
+            tmpInfo.append(tr("Thank you for updating profile changer widget from version %1 to %2.").arg(oldVersion).arg(curVersion));
         }
         tmpInfo.append("\n");
         tmpInfo.append(tr("Feel free to support my work by testing the application in order to get it to Extras -repository."));
@@ -103,7 +103,7 @@ void SettingsDialog::on_buttonDonate_clicked()
     //TODO
     //this->openBrowser("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=");
     //this->close();
-    this->showQuestion("ToDo");
+    this->showInformation(tr("Not yet implemented."));
 }
 
 void SettingsDialog::on_buttonBox_accepted()
